@@ -3,8 +3,6 @@ package duo
 import (
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	duoAskCmd "gitlab.com/gitlab-org/cli/internal/commands/duo/ask"
-	"gitlab.com/gitlab-org/cli/internal/commands/duo/claude"
-	"gitlab.com/gitlab-org/cli/internal/commands/duo/codex"
 
 	"github.com/spf13/cobra"
 )
@@ -17,8 +15,6 @@ func NewCmdDuo(f cmdutils.Factory) *cobra.Command {
 	}
 
 	duoCmd.AddCommand(duoAskCmd.NewCmdAsk(f))
-	duoCmd.AddCommand(claude.NewCmdClaude(f))
-	duoCmd.AddCommand(codex.NewCmdCodex(f))
 
 	return duoCmd
 }
