@@ -8,6 +8,8 @@ import (
 	"strconv"
 	"strings"
 
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
+
 	"github.com/AlecAivazis/survey/v2"
 	"gitlab.com/gitlab-org/cli/internal/commands/issue/issueutils"
 	"gitlab.com/gitlab-org/cli/internal/prompt"
@@ -115,6 +117,9 @@ func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 				headRepoOverride(opts, repoOverride)
 			}
 		},
+		Annotations: map[string]string{
+			mcpannotations.Destructive: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			opts.complete(cmd)
 
@@ -157,7 +162,7 @@ func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 	mrCreateCmd.Flags().BoolVarP(&opts.web, "web", "w", false, "Continue merge request creation in a browser.")
 	mrCreateCmd.Flags().BoolVarP(&opts.CopyIssueLabels, "copy-issue-labels", "", false, "Copy labels from issue to the merge request. Used with --related-issue.")
 	mrCreateCmd.Flags().StringVarP(&opts.RelatedIssue, "related-issue", "i", "", "Create a merge request for an issue. If --title is not provided, uses the issue title.")
-	mrCreateCmd.Flags().BoolVar(&opts.recover, "recover", false, "Save the options to a file if the merge request creation fails. If the file exists, the options are loaded from the recovery file. (EXPERIMENTAL.)")
+	mrCreateCmd.Flags().BoolVar(&opts.recover, "recover", false, "Save the options to a file if the merge request creation fails. If the file exists, the options are loaded from the recovery file. (EXPERIMENTAL)")
 	mrCreateCmd.Flags().BoolVar(&opts.signoff, "signoff", false, "Append a DCO signoff to the merge request description.")
 
 	mrCreateCmd.Flags().StringVarP(&opts.MRCreateTargetProject, "target-project", "", "", "Add target project by id, OWNER/REPO, or GROUP/NAMESPACE/REPO.")
@@ -534,7 +539,7 @@ func (o *options) run() error {
 	}
 
 	if action == cmdutils.NoAction {
-		action, err = cmdutils.ConfirmSubmission(true, true)
+		action, err = cmdutils.ConfirmSubmission(o.io, true)
 		if err != nil {
 			return fmt.Errorf("unable to confirm: %w", err)
 		}
@@ -586,7 +591,7 @@ func (o *options) run() error {
 		}
 
 		// Ask the user again but don't permit AddMetadata a second time
-		action, err = cmdutils.ConfirmSubmission(true, false)
+		action, err = cmdutils.ConfirmSubmission(o.io, false)
 		if err != nil {
 			return err
 		}
@@ -795,7 +800,7 @@ func ResolvedHeadRepo(f cmdutils.Factory) func() (glrepo.Interface, error) {
 		if err != nil {
 			return nil, err
 		}
-		headRepo, err := repoContext.HeadRepo(f.IO().PromptEnabled())
+		headRepo, err := repoContext.HeadRepo(f.IO())
 		if err != nil {
 			return nil, err
 		}
