@@ -114,7 +114,7 @@ func (o *options) run() error {
 func Publish(io *iostreams.IOStreams, client *gitlab.Client, repoFullName string, tagName string) error {
 	color := io.Color()
 
-	io.Logf("%s Publishing release %s=%s to the GitLab CI/CD catalog for %s=%s...\n",
+	io.LogInfof("%s Publishing release %s=%s to the GitLab CI/CD catalog for %s=%s...\n",
 		color.ProgressIcon(),
 		color.Blue("tag"), tagName,
 		color.Blue("repo"), repoFullName)
@@ -136,7 +136,7 @@ func Publish(io *iostreams.IOStreams, client *gitlab.Client, repoFullName string
 		return err
 	}
 
-	io.Logf("%s Release published: %s=%s\n", color.GreenCheck(),
+	io.LogInfof("%s Release published: %s=%s\n", color.GreenCheck(),
 		color.Blue("url"), response.CatalogUrl)
 
 	return nil
