@@ -17,6 +17,7 @@ import (
 	configCmd "gitlab.com/gitlab-org/cli/internal/commands/config"
 	deployKeyCmd "gitlab.com/gitlab-org/cli/internal/commands/deploy-key"
 	duoCmd "gitlab.com/gitlab-org/cli/internal/commands/duo"
+	gpgCmd "gitlab.com/gitlab-org/cli/internal/commands/gpg-key"
 	"gitlab.com/gitlab-org/cli/internal/commands/help"
 	incidentCmd "gitlab.com/gitlab-org/cli/internal/commands/incident"
 	issueCmd "gitlab.com/gitlab-org/cli/internal/commands/issue"
@@ -40,19 +41,6 @@ import (
 	versionCmd "gitlab.com/gitlab-org/cli/internal/commands/version"
 )
 
-// setHelpFuncRecursively sets the help function on a command and all its subcommands
-func setHelpFuncRecursively(cmd *cobra.Command, f cmdutils.Factory) {
-	// Set help function for this command
-	cmd.SetHelpFunc(func(command *cobra.Command, args []string) {
-		help.RootHelpFunc(f.IO().Color(), command, args)
-	})
-
-	// Recursively set help function for all subcommands
-	for _, subCmd := range cmd.Commands() {
-		setHelpFuncRecursively(subCmd, f)
-	}
-}
-
 // NewCmdRoot is the main root/parent command
 func NewCmdRoot(f cmdutils.Factory) *cobra.Command {
 	c := f.IO().Color()
@@ -154,6 +142,7 @@ func NewCmdRoot(f cmdutils.Factory) *cobra.Command {
 	rootCmd.AddCommand(projectCmd.NewCmdRepo(f))
 	rootCmd.AddCommand(releaseCmd.NewCmdRelease(f))
 	rootCmd.AddCommand(sshCmd.NewCmdSSHKey(f))
+	rootCmd.AddCommand(gpgCmd.NewCmdGPGKey(f))
 	rootCmd.AddCommand(userCmd.NewCmdUser(f))
 	rootCmd.AddCommand(variableCmd.NewVariableCmd(f))
 	rootCmd.AddCommand(apiCmd.NewCmdApi(f, nil))
@@ -172,9 +161,6 @@ func NewCmdRoot(f cmdutils.Factory) *cobra.Command {
 	// Add global repo override flag but keep it hidden
 	cmdutils.AddGlobalRepoOverride(rootCmd, f)
 
-	// Set help function recursively on all commands to filter out deprecated/hidden commands
-	setHelpFuncRecursively(rootCmd, f)
-
 	rootCmd.Flags().BoolP("version", "v", false, "show glab version information")
 	return rootCmd
 }
