@@ -5,6 +5,8 @@ import (
 	"fmt"
 	"strconv"
 
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
+
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
@@ -24,6 +26,9 @@ func NewCmdGet(f cmdutils.Factory) *cobra.Command {
 			# Get details of a project's secure file using the 'show' alias.
 			$ glab securefile show 1
 		`),
+		Annotations: map[string]string{
+			mcpannotations.Safe: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			client, err := f.GitLabClient()
 			if err != nil {
