@@ -4,13 +4,16 @@ import (
 	"errors"
 	"fmt"
 	"testing"
+	"time"
 
-	"gitlab.com/gitlab-org/cli/api"
-	"gitlab.com/gitlab-org/cli/pkg/git"
-	"gitlab.com/gitlab-org/cli/pkg/prompt"
+	"gitlab.com/gitlab-org/cli/internal/api"
+	"gitlab.com/gitlab-org/cli/internal/git"
+	"gitlab.com/gitlab-org/cli/internal/glinstance"
+	"gitlab.com/gitlab-org/cli/internal/iostreams"
 
 	"github.com/hashicorp/go-multierror"
 	"github.com/stretchr/testify/assert"
+	"github.com/survivorbat/huhtest"
 	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
@@ -109,7 +112,7 @@ func Test_ResolveRemotesToRepos(t *testing.T) {
 
 	// Test the normal and most expected usage
 	t.Run("simple", func(t *testing.T) {
-		r, err := ResolveRemotesToRepos(rem.remotes, rem.apiClient, "")
+		r, err := ResolveRemotesToRepos(rem.remotes, rem.apiClient, glinstance.DefaultHostname)
 		assert.Nil(t, err)
 
 		assert.Equal(t, rem.apiClient, r.apiClient)
@@ -122,43 +125,6 @@ func Test_ResolveRemotesToRepos(t *testing.T) {
 			assert.Equal(t, r.remotes[i].Repo.RepoHost(), rem.remotes[i].Repo.RepoHost())
 		}
 	})
-
-	// Test the usage of baseOverride
-	t.Run("baseOverride", func(t *testing.T) {
-		expectedBaseOverride := NewWithHost("profclems", "glab", "gitlab.com")
-
-		r, err := ResolveRemotesToRepos(rem.remotes, rem.apiClient, "gitlab.com/profclems/glab")
-		assert.Nil(t, err)
-
-		assert.Equal(t, expectedBaseOverride.FullName(), r.baseOverride.FullName())
-		assert.Equal(t, expectedBaseOverride.RepoHost(), r.baseOverride.RepoHost())
-
-		assert.Equal(t, rem.apiClient, r.apiClient)
-
-		assert.Len(t, r.remotes, 1)
-
-		for i := range r.remotes {
-			assert.Equal(t, r.remotes[i].Name, rem.remotes[i].Name)
-			assert.Equal(t, r.remotes[i].Repo.FullName(), rem.remotes[i].Repo.FullName())
-			assert.Equal(t, r.remotes[i].Repo.RepoHost(), rem.remotes[i].Repo.RepoHost())
-		}
-	})
-
-	// Test the usage of baseOverride when it is passed an invalid value
-	t.Run("baseOverrideFail", func(t *testing.T) {
-		r, err := ResolveRemotesToRepos(rem.remotes, rem.apiClient, "badValue")
-		assert.EqualError(t, err, `expected the "[HOST/]OWNER/[NAMESPACE/]REPO" format, got "badValue"`)
-
-		assert.Equal(t, rem.apiClient, r.apiClient)
-
-		assert.Len(t, r.remotes, 1)
-
-		for i := range r.remotes {
-			assert.Equal(t, r.remotes[i].Name, rem.remotes[i].Name)
-			assert.Equal(t, r.remotes[i].Repo.FullName(), rem.remotes[i].Repo.FullName())
-			assert.Equal(t, r.remotes[i].Repo.RepoHost(), rem.remotes[i].Repo.RepoHost())
-		}
-	})
 }
 
 func Test_resolveNetwork(t *testing.T) {
@@ -201,6 +167,11 @@ func Test_resolveNetwork(t *testing.T) {
 		// Make our own copy of rem we can modify
 		rem := *rem
 
+		// Override api.GetProject so it doesn't mess with other tests
+		originalGetProject := api.GetProject
+		defer func() {
+			api.GetProject = originalGetProject
+		}()
 		api.GetProject = func(_ *gitlab.Client, ProjectID any) (*gitlab.Project, error) {
 			return nil, assert.AnError
 		}
@@ -267,33 +238,31 @@ func Test_BaseRepo(t *testing.T) {
 	}
 
 	// Override git.SetRemoteResolution so it doesn't mess with the user configs
+	originalSetRemoteResolution := git.SetRemoteResolution
+	defer func() {
+		git.SetRemoteResolution = originalSetRemoteResolution
+	}()
 	git.SetRemoteResolution = func(_, _ string) error {
 		return nil
 	}
 
+	// Override api.GetProject so it doesn't mess with other tests
+	originalGetProject := api.GetProject
+	defer func() {
+		api.GetProject = originalGetProject
+	}()
 	api.GetProject = func(_ *gitlab.Client, projectID any) (*gitlab.Project, error) {
 		p := mockGitlabProject(projectID)
 		return &p, nil
 	}
 
-	t.Run("baseOverride", func(t *testing.T) {
-		localRem := rem()
-		localRem.baseOverride = NewWithHost("profclems", "glab", "gitlab.com")
-
-		got, err := localRem.BaseRepo(false)
-		assert.NoError(t, err)
-
-		assert.Equal(t, localRem.baseOverride.FullName(), got.FullName())
-		assert.Equal(t, localRem.baseOverride.RepoHost(), got.RepoHost())
-	})
-
 	t.Run("Resolved->base", func(t *testing.T) {
 		localRem := rem()
 
 		// Set a base resolution
 		localRem.remotes[0].Resolved = "base"
 
-		got, err := localRem.BaseRepo(false)
+		got, err := localRem.BaseRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, localRem.remotes[0].FullName(), got.FullName())
@@ -308,7 +277,7 @@ func Test_BaseRepo(t *testing.T) {
 		// Set a base resolution
 		localRem.remotes[0].Resolved = "base: gitlab.com/maxice8/glab"
 
-		got, err := localRem.BaseRepo(false)
+		got, err := localRem.BaseRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, expectedResolution.FullName(), got.FullName())
@@ -321,7 +290,7 @@ func Test_BaseRepo(t *testing.T) {
 		// Set a base resolution
 		localRem.remotes[0].Resolved = "base:NotAnActualValidValue"
 
-		got, err := localRem.BaseRepo(false)
+		got, err := localRem.BaseRepo(iostreams.New())
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `expected the "[HOST/]OWNER/[NAMESPACE/]REPO" format, got "NotAnActualValidValue"`)
 	})
@@ -334,7 +303,7 @@ func Test_BaseRepo(t *testing.T) {
 		// Set a base resolution
 		localRem.remotes[0].Resolved = "gitlab.com/maxice8/glab"
 
-		got, err := localRem.BaseRepo(false)
+		got, err := localRem.BaseRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, expectedResolution.FullName(), got.FullName())
@@ -347,7 +316,7 @@ func Test_BaseRepo(t *testing.T) {
 		// Set a base resolution
 		localRem.remotes[0].Resolved = "NotAnActualValidValue"
 
-		got, err := localRem.BaseRepo(false)
+		got, err := localRem.BaseRepo(iostreams.New())
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `expected the "[HOST/]OWNER/[NAMESPACE/]REPO" format, got "NotAnActualValidValue"`)
 	})
@@ -355,7 +324,7 @@ func Test_BaseRepo(t *testing.T) {
 	t.Run("Prompt==false", func(t *testing.T) {
 		localRem := rem()
 
-		got, err := localRem.BaseRepo(false)
+		got, err := localRem.BaseRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, localRem.remotes[0].FullName(), got.FullName())
@@ -366,7 +335,7 @@ func Test_BaseRepo(t *testing.T) {
 		localRem := rem()
 
 		// Prompt must be true otherwise we won't reach the code we want to test
-		got, err := localRem.BaseRepo(true)
+		got, err := localRem.BaseRepo(iostreams.New(iostreams.WithStdout(nil, true), iostreams.WithStderr(nil, true)))
 		assert.NoError(t, err)
 
 		assert.Equal(t, localRem.remotes[0].FullName(), got.FullName())
@@ -380,7 +349,7 @@ func Test_BaseRepo(t *testing.T) {
 		localRem.remotes = Remotes{}
 		localRem.network = nil
 
-		_, err := localRem.BaseRepo(true)
+		_, err := localRem.BaseRepo(iostreams.New(iostreams.WithStdout(nil, true), iostreams.WithStderr(nil, true)))
 		assert.EqualError(t, err, "no GitLab Projects found from remotes")
 	})
 
@@ -402,17 +371,14 @@ func Test_BaseRepo(t *testing.T) {
 		localRem.network = append(localRem.network, originNetwork)
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the base repository", 1).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "base",
-				Value: "maxice8/glab", // We expect to get `origin`
-			},
-		})
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
 
-		got, err := localRem.BaseRepo(true)
+		got, err := localRem.BaseRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, originRemote.Repo.FullName(), got.FullName())
@@ -437,17 +403,14 @@ func Test_BaseRepo(t *testing.T) {
 		localRem.network = append(localRem.network, originNetwork)
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the base repository", 0).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "base",
-				Value: "profclems/glab", // We expect to get `origin`
-			},
-		})
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
 
-		got, err := localRem.BaseRepo(true)
+		got, err := localRem.BaseRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, localRem.remotes[0].Repo.FullName(), got.FullName())
@@ -477,17 +440,14 @@ func Test_BaseRepo(t *testing.T) {
 		localRem.network = []gitlab.Project{originNetwork}
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the base repository", 1).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "base",
-				Value: "maxice8/glab", // We expect to get `origin`
-			},
-		})
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
 
-		got, err := localRem.BaseRepo(true)
+		got, err := localRem.BaseRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, originRemote.Repo.FullName(), got.FullName())
@@ -517,57 +477,26 @@ func Test_BaseRepo(t *testing.T) {
 		localRem.network = []gitlab.Project{originNetwork}
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the base repository", 0).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "base",
-				Value: "profclems/glab", // We expect to get `origin`
-			},
-		})
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
 
-		got, err := localRem.BaseRepo(true)
+		got, err := localRem.BaseRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, "profclems/glab", got.FullName())
 		assert.Equal(t, "gitlab.com", got.RepoHost())
 	})
 
-	t.Run("Consult the network, multiple projects, prompt fails", func(t *testing.T) {
-		localRem := rem()
-
-		originRemote := &Remote{
-			Remote: &git.Remote{Name: "origin"},
-			Repo:   NewWithHost("maxice8", "glab", "gitlab.com"),
-		}
-
-		originNetwork := gitlab.Project{
-			ID:                2,
-			PathWithNamespace: "maxice8/glab",
-			HTTPURLToRepo:     "https://gitlab.com/maxice8/glab",
-		}
-
-		localRem.remotes = append(localRem.remotes, originRemote)
-		localRem.network = append(localRem.network, originNetwork)
-
-		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
-
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "base",
-				Value: errors.New("could not prompt"),
-			},
-		})
-
-		got, err := localRem.BaseRepo(true)
-		assert.Nil(t, got)
-		assert.EqualError(t, err, "could not prompt")
-	})
-
 	t.Run("Consult the network, all calls fail", func(t *testing.T) {
+		// Override api.GetProject so it doesn't mess with other tests
+		originalGetProject := api.GetProject
+		defer func() {
+			api.GetProject = originalGetProject
+		}()
 		api.GetProject = func(_ *gitlab.Client, projectID any) (*gitlab.Project, error) {
 			return nil, assert.AnError
 		}
@@ -582,13 +511,18 @@ func Test_BaseRepo(t *testing.T) {
 		localRem.network = nil
 
 		// Prompt must be true otherwise we won't reach the code we want to test
-		_, err := localRem.BaseRepo(true)
+		_, err := localRem.BaseRepo(iostreams.New(iostreams.WithStdout(nil, true), iostreams.WithStderr(nil, true)))
 		multierr := err.(*multierror.Error)
 		assert.Len(t, multierr.Errors, 2)
 		assert.True(t, errors.Is(err, assert.AnError), "Unexpected error type")
 	})
 
 	t.Run("Consult the network, some, but not all, calls fail", func(t *testing.T) {
+		// Override api.GetProject so it doesn't mess with other tests
+		originalGetProject := api.GetProject
+		defer func() {
+			api.GetProject = originalGetProject
+		}()
 		api.GetProject = func(_ *gitlab.Client, projectID any) (*gitlab.Project, error) {
 			if projectID == "profclems/glab" {
 				return &gitlab.Project{
@@ -610,9 +544,70 @@ func Test_BaseRepo(t *testing.T) {
 		localRem.network = nil
 
 		// Prompt must be true otherwise we won't reach the code we want to test
-		_, err := localRem.BaseRepo(true)
+		_, err := localRem.BaseRepo(iostreams.New(iostreams.WithStdout(nil, true), iostreams.WithStderr(nil, true)))
 		assert.NoError(t, err)
 	})
+
+	t.Run("Host mismatch: API host differs from git remote host", func(t *testing.T) {
+		// This test verifies our fix for the host mismatch bug
+		// where the API returns a different host than the git remote
+		// Git remote uses git.example.com, but API returns api.example.com
+		localRem := &ResolvedRemotes{
+			remotes: Remotes{
+				&Remote{
+					Remote: &git.Remote{
+						Name: "origin",
+					},
+					Repo: NewWithHost("owner", "repo", "git.example.com"), // Git remote uses git host
+				},
+			},
+			apiClient: &gitlab.Client{},
+			network: []gitlab.Project{
+				{
+					ID:                1,
+					PathWithNamespace: "owner/repo",
+					HTTPURLToRepo:     "https://api.example.com/owner/repo.git", // API returns api.example.com, different from git remote's git.example.com
+				},
+			},
+		}
+
+		// Override git.SetRemoteResolution so it doesn't mess with the user configs
+		originalSetRemoteResolution := git.SetRemoteResolution
+		defer func() {
+			git.SetRemoteResolution = originalSetRemoteResolution
+		}()
+		git.SetRemoteResolution = func(_, _ string) error {
+			return nil
+		}
+
+		// Override api.GetProject so it doesn't mess with other tests
+		originalGetProject := api.GetProject
+		defer func() {
+			api.GetProject = originalGetProject
+		}()
+		api.GetProject = func(_ *gitlab.Client, projectID any) (*gitlab.Project, error) {
+			p := &gitlab.Project{
+				PathWithNamespace: fmt.Sprint(projectID),
+				HTTPURLToRepo:     "https://api.example.com/owner/repo.git", // API returns api.example.com, different from git remote's git.example.com
+			}
+			return p, nil
+		}
+
+		// Mock the prompt to select the first (and only) project
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the base repository", 0).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
+
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
+
+		got, err := localRem.BaseRepo(ios)
+		assert.NoError(t, err)
+
+		// The fix should ensure we use the git remote host, not the API host
+		assert.Equal(t, "owner/repo", got.FullName())
+		assert.Equal(t, "git.example.com", got.RepoHost()) // Should use git remote host, not API host
+	})
 }
 
 func Test_HeadRepo(t *testing.T) {
@@ -648,33 +643,31 @@ func Test_HeadRepo(t *testing.T) {
 	}
 
 	// Override git.SetRemoteResolution so it doesn't mess with the user configs
+	originalSetRemoteResolution := git.SetRemoteResolution
+	defer func() {
+		git.SetRemoteResolution = originalSetRemoteResolution
+	}()
 	git.SetRemoteResolution = func(_, _ string) error {
 		return nil
 	}
 
+	// Override api.GetProject so it doesn't mess with other tests
+	originalGetProject := api.GetProject
+	defer func() {
+		api.GetProject = originalGetProject
+	}()
 	api.GetProject = func(_ *gitlab.Client, projectID any) (*gitlab.Project, error) {
 		p := mockGitlabProject(projectID)
 		return &p, nil
 	}
 
-	t.Run("baseOverride", func(t *testing.T) {
-		localRem := rem()
-		localRem.baseOverride = NewWithHost("profclems", "glab", "gitlab.com")
-
-		got, err := localRem.HeadRepo(false)
-		assert.NoError(t, err)
-
-		assert.Equal(t, localRem.baseOverride.FullName(), got.FullName())
-		assert.Equal(t, localRem.baseOverride.RepoHost(), got.RepoHost())
-	})
-
 	t.Run("Resolved->head", func(t *testing.T) {
 		localRem := rem()
 
 		// Set a head resolution
 		localRem.remotes[0].Resolved = "head"
 
-		got, err := localRem.HeadRepo(false)
+		got, err := localRem.HeadRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, localRem.remotes[0].FullName(), got.FullName())
@@ -689,7 +682,7 @@ func Test_HeadRepo(t *testing.T) {
 		// Set a base resolution
 		localRem.remotes[0].Resolved = "head: gitlab.com/maxice8/glab"
 
-		got, err := localRem.HeadRepo(false)
+		got, err := localRem.HeadRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, expectedResolution.FullName(), got.FullName())
@@ -702,7 +695,7 @@ func Test_HeadRepo(t *testing.T) {
 		// Set a base resolution
 		localRem.remotes[0].Resolved = "head:NotAnActualValidValue"
 
-		got, err := localRem.HeadRepo(false)
+		got, err := localRem.HeadRepo(iostreams.New())
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `expected the "[HOST/]OWNER/[NAMESPACE/]REPO" format, got "NotAnActualValidValue"`)
 	})
@@ -710,7 +703,7 @@ func Test_HeadRepo(t *testing.T) {
 	t.Run("Prompt==false", func(t *testing.T) {
 		localRem := rem()
 
-		got, err := localRem.HeadRepo(false)
+		got, err := localRem.HeadRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, localRem.remotes[0].FullName(), got.FullName())
@@ -720,7 +713,7 @@ func Test_HeadRepo(t *testing.T) {
 		localRem := rem()
 
 		// Prompt must be true otherwise we won't reach the code we want to test
-		got, err := localRem.HeadRepo(false)
+		got, err := localRem.HeadRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, got.FullName(), localRem.remotes[0].FullName())
@@ -748,7 +741,7 @@ func Test_HeadRepo(t *testing.T) {
 		localRem.remotes = Remotes{originRemote}
 		localRem.network = []gitlab.Project{originNetwork}
 
-		got, err := localRem.HeadRepo(false)
+		got, err := localRem.HeadRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, "maxice8/glab", got.FullName())
@@ -771,7 +764,7 @@ func Test_HeadRepo(t *testing.T) {
 		localRem.remotes = append(localRem.remotes, originRemote)
 		localRem.network = append(localRem.network, originNetwork)
 
-		got, err := localRem.HeadRepo(false)
+		got, err := localRem.HeadRepo(iostreams.New())
 		assert.NoError(t, err)
 
 		assert.Equal(t, "profclems/glab", got.FullName())
@@ -784,7 +777,7 @@ func Test_HeadRepo(t *testing.T) {
 		localRem.remotes = Remotes{}
 		localRem.network = nil
 
-		_, err := localRem.HeadRepo(true)
+		_, err := localRem.HeadRepo(iostreams.New(iostreams.WithStdout(nil, true), iostreams.WithStderr(nil, true)))
 		assert.EqualError(t, err, "no GitLab Projects found from remotes")
 	})
 
@@ -806,17 +799,13 @@ func Test_HeadRepo(t *testing.T) {
 		localRem.network = append(localRem.network, originNetwork)
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the head repository", 1).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "head",
-				Value: "maxice8/glab", // We expect to get `origin`
-			},
-		})
-
-		got, err := localRem.HeadRepo(true)
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
+		got, err := localRem.HeadRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, originRemote.Repo.FullName(), got.FullName())
@@ -841,17 +830,13 @@ func Test_HeadRepo(t *testing.T) {
 		localRem.network = append(localRem.network, originNetwork)
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the head repository", 0).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "head",
-				Value: "profclems/glab", // We expect to get `origin`
-			},
-		})
-
-		got, err := localRem.HeadRepo(true)
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
+		got, err := localRem.HeadRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, localRem.remotes[0].Repo.FullName(), got.FullName())
@@ -881,17 +866,13 @@ func Test_HeadRepo(t *testing.T) {
 		localRem.network = []gitlab.Project{originNetwork}
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the head repository", 1).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "head",
-				Value: "maxice8/glab", // We expect to get `origin`
-			},
-		})
-
-		got, err := localRem.HeadRepo(true)
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
+		got, err := localRem.HeadRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, originRemote.Repo.FullName(), got.FullName())
@@ -921,53 +902,76 @@ func Test_HeadRepo(t *testing.T) {
 		localRem.network = []gitlab.Project{originNetwork}
 
 		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the head repository", 0).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "head",
-				Value: "profclems/glab", // We expect to get `origin`
-			},
-		})
-
-		got, err := localRem.HeadRepo(true)
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
+		got, err := localRem.HeadRepo(ios)
 		assert.NoError(t, err)
 
 		assert.Equal(t, "profclems/glab", got.FullName())
 		assert.Equal(t, "gitlab.com", got.RepoHost())
 	})
 
-	t.Run("Consult the network, multiple projects, prompt fails", func(t *testing.T) {
-		localRem := rem()
-
-		originRemote := &Remote{
-			Remote: &git.Remote{Name: "origin"},
-			Repo:   NewWithHost("maxice8", "glab", "gitlab.com"),
-		}
-
-		originNetwork := gitlab.Project{
-			ID:                2,
-			PathWithNamespace: "maxice8/glab",
-			HTTPURLToRepo:     "https://gitlab.com/maxice8/glab",
-		}
-
-		localRem.remotes = append(localRem.remotes, originRemote)
-		localRem.network = append(localRem.network, originNetwork)
-
-		// Mock the prompt
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
-
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "head",
-				Value: errors.New("could not prompt"),
+	t.Run("Host mismatch: API host differs from git remote host", func(t *testing.T) {
+		// This test verifies our fix for the host mismatch bug
+		// where the API returns a different host than the git remote
+		// Git remote uses git.example.com, but API returns api.example.com
+		localRem := &ResolvedRemotes{
+			remotes: Remotes{
+				&Remote{
+					Remote: &git.Remote{
+						Name: "origin",
+					},
+					Repo: NewWithHost("owner", "repo", "git.example.com"), // Git remote uses git host
+				},
 			},
-		})
+			apiClient: &gitlab.Client{},
+			network: []gitlab.Project{
+				{
+					ID:                1,
+					PathWithNamespace: "owner/repo",
+					HTTPURLToRepo:     "https://api.example.com/owner/repo.git", // API returns api.example.com, different from git remote's git.example.com
+				},
+			},
+		}
 
-		got, err := localRem.HeadRepo(true)
-		assert.Nil(t, got)
-		assert.EqualError(t, err, "could not prompt")
+		// Override git.SetRemoteResolution so it doesn't mess with the user configs
+		originalSetRemoteResolution := git.SetRemoteResolution
+		defer func() {
+			git.SetRemoteResolution = originalSetRemoteResolution
+		}()
+		git.SetRemoteResolution = func(_, _ string) error {
+			return nil
+		}
+
+		// Override api.GetProject so it doesn't mess with other tests
+		originalGetProject := api.GetProject
+		defer func() {
+			api.GetProject = originalGetProject
+		}()
+		api.GetProject = func(_ *gitlab.Client, projectID any) (*gitlab.Project, error) {
+			p := &gitlab.Project{
+				PathWithNamespace: fmt.Sprint(projectID),
+				HTTPURLToRepo:     "https://api.example.com/owner/repo.git", // API returns api.example.com, different from git remote's git.example.com
+			}
+			return p, nil
+		}
+
+		// Mock the prompt to select the first (and only) project
+		stdin, stdout, cancel := huhtest.NewResponder().
+			AddSelect("Which should be the head repository", 0).MatchRegexp(). // We expect to get `origin`
+			Start(t, 1*time.Hour)
+		t.Cleanup(cancel)
+
+		ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true), iostreams.WithStderr(nil, true))
+		got, err := localRem.HeadRepo(ios)
+		assert.NoError(t, err)
+
+		// The fix should ensure we use the git remote host, not the API host
+		assert.Equal(t, "owner/repo", got.FullName())
+		assert.Equal(t, "git.example.com", got.RepoHost()) // Should use git remote host, not API host
 	})
 }
